@@ -1,7 +1,7 @@
 package IOD::Examples;
 
-our $DATE = '2015-03-20'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $DATE = '2015-03-26'; # DATE
+our $VERSION = '0.13'; # VERSION
 
 1;
 # ABSTRACT: Example IOD configuration files
@@ -18,7 +18,18 @@ IOD::Examples - Example IOD configuration files
 
 =head1 VERSION
 
-This document describes version 0.12 of IOD::Examples (from Perl distribution IOD-Examples), released on 2015-03-20.
+This document describes version 0.13 of IOD::Examples (from Perl distribution IOD-Examples), released on 2015-03-26.
+
+=head1 DESCRIPTION
+
+This distribution contains various examples of L<IOD> configuration files in its
+per-dist share dir. It also serves as a spectest.
+
+=head1 SEE ALSO
+
+L<IOD>
+
+L<Config::IOD>, L<Config::IOD::Reader>
 
 =head1 HOMEPAGE
 
